pub struct Posting {
pub account: Account,
pub units: Option<IncompleteAmount>,
pub cost: Option<CostSpec>,
pub price: Option<PriceAnnotation>,
pub flag: Option<char>,
pub meta: Metadata,
pub comments: Vec<String>,
pub trailing_comments: Vec<String>,
}Expand description
A posting within a transaction.
Postings represent the individual legs of a transaction. Each posting specifies an account and optionally an amount, cost, and price.
When the units are None, the entire amount will be inferred by the
interpolation algorithm to balance the transaction. When units is
Some(IncompleteAmount), it may still have missing components that
need to be filled in.
Fields
account: AccountThe account for this posting
units: Option<IncompleteAmount>The units (may be incomplete or None for auto-calculated postings)
cost: Option<CostSpec>Cost specification for the position
price: Option<PriceAnnotation>Price annotation (@ or @@)
flag: Option<char>Whether this posting has the “!” flag
meta: MetadataPosting metadata
comments: Vec<String>Comments that appear before this posting (one per line)
trailing_comments: Vec<String>Trailing comment(s) on the same line as the posting
Implementations
Sourceimpl Posting
impl Posting
Sourcepub fn new(account: impl Into<Account>, units: Amount) -> Self
pub fn new(account: impl Into<Account>, units: Amount) -> Self
Create a new posting with the given account and complete units.
Sourcepub fn with_incomplete(
account: impl Into<Account>,
units: IncompleteAmount,
) -> Self
pub fn with_incomplete( account: impl Into<Account>, units: IncompleteAmount, ) -> Self
Create a new posting with an incomplete amount.
Sourcepub fn auto(account: impl Into<Account>) -> Self
pub fn auto(account: impl Into<Account>) -> Self
Create a posting without any amount (to be fully interpolated).
Sourcepub fn with_cost(self, cost: CostSpec) -> Self
pub fn with_cost(self, cost: CostSpec) -> Self
Add a cost specification.
Consuming builder — takes self by value and returns Posting.
To apply this to a Spanned<Posting> while preserving its source
location, use crate::Spanned::map:
let spanned: Spanned<Posting> = Spanned::synthesized(
Posting::new("Assets:Stock", Amount::new(dec!(10), "AAPL"))
);
let with_cost: Spanned<Posting> = spanned.map(|p| p.with_cost(cost));Sourcepub fn with_price(self, price: PriceAnnotation) -> Self
pub fn with_price(self, price: PriceAnnotation) -> Self
Add a price annotation.
See Self::with_cost for the Spanned<Posting> pattern.
Sourcepub const fn with_flag(self, flag: char) -> Self
pub const fn with_flag(self, flag: char) -> Self
Add a flag.
See Self::with_cost for the Spanned<Posting> pattern.