Extract unique accounts, currencies, and payees from directives.
These functions are used by both the WASM editor and LSP for completions.
Constants
- DEFAULT_
CURRENCIES - Common default currencies included in completions.
Functions
- extract_
accounts - Extract unique account names from directives (sorted, deduplicated).
- extract_
accounts_ iter - Extract unique account names from an iterator of directive references.
- extract_
currencies - Extract unique currencies from directives (sorted, deduplicated).
- extract_
currencies_ iter - Extract unique currencies from an iterator of directive references.
- extract_
payees - Extract unique payees from transactions (sorted, deduplicated).
- extract_
payees_ iter - Extract unique payees from an iterator of directive references.