pub enum ReductionScope {
AllPositions,
CostBearingOnly,
}Expand description
Controls which positions are considered when checking whether incoming units reduce (i.e. have the opposite sign of) an existing inventory.
AllPositions: every position is considered, regardless of whether it carries a cost.CostBearingOnly: only positions with a cost are considered. This prevents a negative simple (no-cost) position — left behind by a sell-without-cost-spec — from causing a subsequent cost-bearing augmentation to be misclassified as a reduction. See: issue #875, beancount#889.
Variants
AllPositions
Consider all positions (cost-bearing and simple).
CostBearingOnly
Consider only positions that carry a cost.