Module span

Module span 

Source location tracking.

Structs

ArchivedSpan
An archived Span
ArchivedSpanned
An archived Spanned
Span
A span in the source code, represented as a byte range.
SpanResolver
The resolver for an archived Span
Spanned
A value with an associated source location (span and file).
SpannedResolver
The resolver for an archived Spanned

Constants

SYNTHESIZED_FILE_ID
Sentinel file_id indicating a directive was synthesized by a plugin rather than parsed from a source file.

Traits

ShiftSpans
Shift every Span reachable inside self by applying shift.