Module extract

Module extract 

Extract unique accounts, currencies, and payees from directives.

These functions are used by both the WASM editor and LSP for completions.

Constants

DEFAULT_CURRENCIES
Common default currencies included in completions.

Functions

extract_accounts
Extract unique account names from directives (sorted, deduplicated).
extract_accounts_iter
Extract unique account names from an iterator of directive references.
extract_currencies
Extract unique currencies from directives (sorted, deduplicated).
extract_currencies_iter
Extract unique currencies from an iterator of directive references.
extract_payees
Extract unique payees from transactions (sorted, deduplicated).
extract_payees_iter
Extract unique payees from an iterator of directive references.